@@ -1,23 +1,27 @@
-from py.test import raises
-from sqlobject import *
-from sqlobject.tests.dbtest import *
+from py.test import raises, skip
+from sqlobject import ForeignKey, MultipleJoin, StringCol
 from sqlobject.inheritance import InheritableSQLObject
+from sqlobject.tests.dbtest import getConnection, setupClass, supports
 
 ########################################
-## Deep Inheritance
+# Deep Inheritance
 ########################################
 
+
 class DIPerson(InheritableSQLObject):
     firstName = StringCol(length=100)
     lastName = StringCol(alternateID=True, length=255)
     manager = ForeignKey("DIManager", default=None)
 
+
 class DIEmployee(DIPerson):
     position = StringCol(unique=True, length=100)
 
+
 class DIManager(DIEmployee):
     subdudes = MultipleJoin("DIPerson", joinColumn="manager_id")
 
+
 def test_creation_fail():
     """
     Try to create a Manager without specifying a position.
@@ -27,11 +31,12 @@ def test_creation_fail():
     """
     setupClass([DIManager, DIEmployee, DIPerson])
 
-    kwargs ={'firstName': 'John', 'lastname': 'Doe'}
+    kwargs = {'firstName': 'John', 'lastname': 'Doe'}
     raises(TypeError, DIManager, **kwargs)
     persons = DIEmployee.select(DIPerson.q.firstName == 'John')
     assert persons.count() == 0
 
+
 def test_creation_fail2():
     """
     Try to create two Managers with the same position.
@@ -41,36 +46,40 @@ def test_creation_fail2():
     """
     setupClass([DIManager, DIEmployee, DIPerson])
 
-    kwargs ={'firstName': 'John', 'lastName': 'Doe', 'position': 'Project Manager'}
+    kwargs = {'firstName': 'John', 'lastName': 'Doe',
+              'position': 'Project Manager'}
     DIManager(**kwargs)
     persons = DIEmployee.select(DIPerson.q.firstName == 'John')
     assert persons.count() == 1
 
-    kwargs ={'firstName': 'John', 'lastName': 'Doe II', 'position': 'Project Manager'}
+    kwargs = {'firstName': 'John', 'lastName': 'Doe II',
+              'position': 'Project Manager'}
     raises(Exception, DIManager, **kwargs)
     persons = DIPerson.select(DIPerson.q.firstName == 'John')
     assert persons.count() == 1
 
     if not supports('transactions'):
-        return
+        skip("Transactions aren't supported")
     transaction = DIPerson._connection.transaction()
-    kwargs ={'firstName': 'John', 'lastName': 'Doe III', 'position': 'Project Manager'}
+    kwargs = {'firstName': 'John', 'lastName': 'Doe III',
+              'position': 'Project Manager'}
     raises(Exception, DIManager, connection=transaction, **kwargs)
     transaction.rollback()
     transaction.begin()
-    persons = DIPerson.select(DIPerson.q.firstName == 'John', connection=transaction)
+    persons = DIPerson.select(DIPerson.q.firstName == 'John',
+                              connection=transaction)
     assert persons.count() == 1
 
+
 def test_deep_inheritance():
     setupClass([DIManager, DIEmployee, DIPerson])
 
     manager = DIManager(firstName='Project', lastName='Manager',
-        position='Project Manager')
+                        position='Project Manager')
     manager_id = manager.id
     employee_id = DIEmployee(firstName='Project', lastName='Leader',
-        position='Project leader', manager=manager).id
-    person_id = DIPerson(firstName='Oneof', lastName='Authors',
-        manager=manager).id
+                             position='Project leader', manager=manager).id
+    DIPerson(firstName='Oneof', lastName='Authors', manager=manager)
 
     conn = getConnection()
     cache = conn.cache
