@@ -2,6 +2,7 @@ from sqlobject.dbconnection import DBAPI
 from sqlobject import col
 import re
 
+
 class MSSQLConnection(DBAPI):
 
     supportTransactions = True
@@ -23,13 +24,16 @@ class MSSQLConnection(DBAPI):
                 elif driver == 'pymssql':
                     import pymssql as sqlmodule
                 else:
-                    raise ValueError('Unknown MSSQL driver "%s", expected adodb or pymssql' % driver)
+                    raise ValueError(
+                        'Unknown MSSQL driver "%s", '
+                        'expected adodb or pymssql' % driver)
             except ImportError:
                 pass
             else:
                 break
         else:
-            raise ImportError('Cannot find an MSSQL driver, tried %s' % drivers)
+            raise ImportError(
+                'Cannot find an MSSQL driver, tried %s' % drivers)
         self.module = sqlmodule
 
         if sqlmodule.__name__ == 'adodbapi':
@@ -45,22 +49,26 @@ class MSSQLConnection(DBAPI):
 
             conn_str += "Data Source=%s;Initial Catalog=%s;"
 
-            # MSDE does not allow SQL server login 
+            # MSDE does not allow SQL server login
             if kw.get("sspi"):
-                conn_str += "Integrated Security=SSPI;Persist Security Info=False"
-                self.make_conn_str = lambda keys: conn_str % (keys.host, keys.db)
+                conn_str += \
+                    "Integrated Security=SSPI;Persist Security Info=False"
+                self.make_conn_str = lambda keys: conn_str % (
+                    keys.host, keys.db)
             else:
                 conn_str += "User Id=%s;Password=%s"
-                self.make_conn_str = lambda keys: conn_str % (keys.host, keys.db, keys.user, keys.password)
+                self.make_conn_str = lambda keys: conn_str % (
+                    keys.host, keys.db, keys.user, keys.password)
 
             kw.pop("sspi", None)
             kw.pop("ncli", None)
 
-        else: # pymssql
+        else:  # pymssql
             self.dbconnection = sqlmodule.connect
             sqlmodule.Binary = lambda st: str(st)
             # don't know whether pymssql uses unicode
             self.usingUnicodeStrings = False
+
             def _make_conn_str(keys):
                 keys_dict = {}
                 for attr, value in (
@@ -70,11 +78,12 @@ class MSSQLConnection(DBAPI):
                     ('port', keys.port),
                     ('database', keys.db),
                 ):
-                    if value: keys_dict[attr] = value
+                    if value:
+                        keys_dict[attr] = value
                 return keys_dict
             self.make_conn_str = _make_conn_str
 
-        self.autoCommit=int(autoCommit)
+        self.autoCommit = int(autoCommit)
         self.user = user
         self.password = password
         self.host = host
@@ -82,6 +91,7 @@ class MSSQLConnection(DBAPI):
         self.db = db
         self._server_version = None
         self._can_use_max_types = None
+        self._can_use_microseconds = None
         DBAPI.__init__(self, **kw)
 
     @classmethod
@@ -119,6 +129,7 @@ class MSSQLConnection(DBAPI):
        where TABLE_NAME = '%s'
        and COLUMNPROPERTY(object_id(TABLE_NAME), COLUMN_NAME, 'IsIdentity') = 1
     """
+
     def _hasIdentity(self, conn, table):
         query = self.HAS_IDENTITY % table
         c = conn.cursor()
@@ -139,7 +150,7 @@ class MSSQLConnection(DBAPI):
             values = [id] + values
         elif has_identity and idName in names:
             try:
-                i = names.index( idName )
+                i = names.index(idName)
                 if i:
                     del names[i]
                     del values[i]
@@ -192,7 +203,8 @@ class MSSQLConnection(DBAPI):
     def joinSQLType(self, join):
         return 'INT NOT NULL'
 
-    SHOW_TABLES="SELECT name FROM sysobjects WHERE type='U'"
+    SHOW_TABLES = "SELECT name FROM sysobjects WHERE type='U'"
+
     def tableExists(self, tableName):
         for (table,) in self.queryAll(self.SHOW_TABLES):
             if table.lower() == tableName.lower():
@@ -205,10 +217,11 @@ class MSSQLConnection(DBAPI):
                     column.mssqlCreateSQL(self)))
 
     def delColumn(self, sqlmeta, column):
-        self.query('ALTER TABLE %s DROP COLUMN %s' % (tableName.table, column.dbName))
+        self.query('ALTER TABLE %s DROP COLUMN %s' % (sqlmeta.table,
+                                                      column.dbName))
 
-    # precision and scale is gotten from column table so that we can create 
-    # decimal columns if needed
+    # Precision and scale is gotten from column table
+    # so that we can create decimal columns if needed.
     SHOW_COLUMNS = """
         select
                 name,
@@ -237,7 +250,8 @@ class MSSQLConnection(DBAPI):
         colData = self.queryAll(self.SHOW_COLUMNS
                                 % tableName)
         results = []
-        for field, size, t, precision, scale, nullAllowed, default, defaultText, is_identity in colData:
+        for (field, size, t, precision, scale, nullAllowed,
+                default, defaultText, is_identity) in colData:
             if field == soClass.sqlmeta.idName:
                 continue
             # precision is needed for decimal columns
@@ -251,10 +265,14 @@ class MSSQLConnection(DBAPI):
                 if defaultText[0] == "'":
                     defaultText = defaultText[1:-1]
                 else:
-                    if t == "int"    : defaultText = int(defaultText)
-                    if t == "float"  : defaultText = float(defaultText)
-                    if t == "numeric": defaultText = float(defaultText)
-                    # TODO need to access the "column" to_python method here--but the object doesn't exists yet
+                    if t == "int":
+                        defaultText = int(defaultText)
+                    if t == "float":
+                        defaultText = float(defaultText)
+                    if t == "numeric":
+                        defaultText = float(defaultText)
+                    # TODO need to access the "column" to_python method here --
+                    # but the object doesn't exists yet.
 
             # @@ skip key...
             kw['default'] = defaultText
@@ -263,20 +281,24 @@ class MSSQLConnection(DBAPI):
         return results
 
     def _setAutoCommit(self, conn, auto):
-        #raise Exception(repr(auto))
+        # raise Exception(repr(auto))
         return
-        #conn.auto_commit = auto
+        # conn.auto_commit = auto
         option = "ON"
         if auto == 0:
             option = "OFF"
         c = conn.cursor()
         c.execute("SET AUTOCOMMIT " + option)
-        conn.setconnectoption(SQL.AUTOCOMMIT, option)
+        # from mx.ODBC.Windows import SQL
+        # connection.setconnectoption(
+        # SQL.AUTOCOMMIT, SQL.AUTOCOMMIT_ON if auto else SQL.AUTOCOMMIT_OFF)
 
     # precision and scale is needed for decimal columns
     def guessClass(self, t, size, precision, scale):
         """
-            Here we take raw values coming out of syscolumns and map to SQLObject class types.
+        Here we take raw values coming out of syscolumns
+        and map to SQLObject class types.
+
         """
         if t.startswith('int'):
             return col.IntCol, {}
@@ -287,26 +309,34 @@ class MSSQLConnection(DBAPI):
         elif t.startswith('char'):
             if self.usingUnicodeStrings:
                 return col.UnicodeCol, {'length': size,
-                                       'varchar': False}
+                                        'varchar': False}
             return col.StringCol, {'length': size,
                                    'varchar': False}
         elif t.startswith('datetime'):
             return col.DateTimeCol, {}
         elif t.startswith('decimal'):
-            return col.DecimalCol, {'size': precision, # be careful for awkward naming
-                                   'precision': scale}
+            # be careful for awkward naming
+            return col.DecimalCol, {'size': precision,
+                                    'precision': scale}
         else:
             return col.Col, {}
 
     def server_version(self):
+        """Get server version:
+            8 - 2000
+            9 - 2005
+            10 - 2008
+            11 - 2012
+        """
         if self._server_version is not None:
             return self._server_version
         try:
-            server_version = self.queryOne("SELECT SERVERPROPERTY('productversion')")[0]
+            server_version = self.queryOne(
+                "SELECT SERVERPROPERTY('productversion')")[0]
             server_version = server_version.split('.')[0]
             server_version = int(server_version)
         except:
-            server_version = None # unknown
+            server_version = None  # unknown
         self._server_version = server_version
         return server_version
 
@@ -317,3 +347,11 @@ class MSSQLConnection(DBAPI):
         self._can_use_max_types = can_use_max_types = \
             (server_version is not None) and (server_version >= 9)
         return can_use_max_types
+
+    def can_use_microseconds(self):
+        if self._can_use_microseconds is not None:
+            return self._can_use_microseconds
+        server_version = self.server_version()
+        self._can_use_microseconds = can_use_microseconds = \
+            (server_version is not None) and (server_version >= 10)
+        return can_use_microseconds
