@@ -1,15 +1,19 @@
-from sqlobject import col
+from sqlobject import col, dberrors
+from sqlobject.compat import PY2
 from sqlobject.dbconnection import DBAPI
-from sqlobject.dberrors import *
+
 
 class ErrorMessage(str):
     def __new__(cls, e, append_msg=''):
-        obj = str.__new__(cls, e[1] + append_msg)
-        obj.code = int(e[0])
+        obj = str.__new__(cls, e.args[1] + append_msg)
+        obj.code = int(e.args[0])
         obj.module = e.__module__
         obj.exception = e.__class__.__name__
         return obj
 
+mysql_Bin = None
+
+
 class MySQLConnection(DBAPI):
 
     supportTransactions = False
@@ -17,7 +21,7 @@ class MySQLConnection(DBAPI):
     schemes = [dbName]
 
     def __init__(self, db, user, password='', host='localhost', port=0, **kw):
-        import MySQLdb, MySQLdb.constants.CR, MySQLdb.constants.ER
+        import MySQLdb, MySQLdb.constants.CR, MySQLdb.constants.ER  # noqa
         self.module = MySQLdb
         self.host = host
         self.port = port
@@ -26,11 +30,11 @@ class MySQLConnection(DBAPI):
         self.password = password
         self.kw = {}
         for key in ("unix_socket", "init_command",
-                "read_default_file", "read_default_group", "conv"):
+                    "read_default_file", "read_default_group", "conv"):
             if key in kw:
                 self.kw[key] = kw.pop(key)
         for key in ("connect_timeout", "compress", "named_pipe", "use_unicode",
-                "client_flag", "local_infile"):
+                    "client_flag", "local_infile"):
             if key in kw:
                 self.kw[key] = int(kw.pop(key))
         for key in ("ssl_key", "ssl_cert", "ssl_ca", "ssl_capath"):
@@ -43,16 +47,23 @@ class MySQLConnection(DBAPI):
         else:
             self.dbEncoding = None
 
-        # MySQLdb < 1.2.1: only ascii
-        # MySQLdb = 1.2.1: only unicode
-        # MySQLdb > 1.2.1: both ascii and unicode
-        self.need_unicode = (self.module.version_info[:3] >= (1, 2, 1)) and (self.module.version_info[:3] < (1, 2, 2))
+        global mysql_Bin
+        if not PY2 and mysql_Bin is None:
+            mysql_Bin = MySQLdb.Binary
+            MySQLdb.Binary = lambda x: mysql_Bin(x).decode(
+                'ascii', errors='surrogateescape')
 
+        if self.module.version_info[:3] < (1, 2, 2):
+            raise ValueError('SQLObject requires MySQLdb 1.2.2 or later')
+
+        self._server_version = None
+        self._can_use_microseconds = None
         DBAPI.__init__(self, **kw)
 
     @classmethod
     def _connectionFromParams(cls, user, password, host, port, path, args):
-        return cls(db=path.strip('/'), user=user or '', password=password or '',
+        return cls(db=path.strip('/'),
+                   user=user or '', password=password or '',
                    host=host or 'localhost', port=port or 0, **args)
 
     def makeConnection(self):
@@ -65,21 +76,25 @@ class MySQLConnection(DBAPI):
                     return dbEncoding + '_' + dbEncoding
                 Connection.character_set_name = character_set_name
         try:
-            conn = self.module.connect(host=self.host, port=self.port,
-                db=self.db, user=self.user, passwd=self.password, **self.kw)
+            conn = self.module.connect(
+                host=self.host, port=self.port, db=self.db,
+                user=self.user, passwd=self.password, **self.kw)
             if self.module.version_info[:3] >= (1, 2, 2):
-                conn.ping(True) # Attempt to reconnect. This setting is persistent.
-        except self.module.OperationalError, e:
-            conninfo = "; used connection string: host=%(host)s, port=%(port)s, db=%(db)s, user=%(user)s" % self.__dict__
-            raise OperationalError(ErrorMessage(e, conninfo))
+                # Attempt to reconnect. This setting is persistent.
+                conn.ping(True)
+        except self.module.OperationalError as e:
+            conninfo = ("; used connection string: "
+                        "host=%(host)s, port=%(port)s, "
+                        "db=%(db)s, user=%(user)s" % self.__dict__)
+            raise dberrors.OperationalError(ErrorMessage(e, conninfo))
 
         if hasattr(conn, 'autocommit'):
             conn.autocommit(bool(self.autoCommit))
 
         if dbEncoding:
-            if hasattr(conn, 'set_character_set'): # MySQLdb 1.2.1 and later
+            if hasattr(conn, 'set_character_set'):  # MySQLdb 1.2.1 and later
                 conn.set_character_set(dbEncoding)
-            else: # pre MySQLdb 1.2.1
+            else:  # pre MySQLdb 1.2.1
                 # works along with monkeypatching code above
                 conn.query("SET NAMES %s" % dbEncoding)
 
@@ -90,12 +105,6 @@ class MySQLConnection(DBAPI):
             conn.autocommit(auto)
 
     def _executeRetry(self, conn, cursor, query):
-        if self.need_unicode and not isinstance(query, unicode):
-            try:
-                query = unicode(query, self.dbEncoding)
-            except UnicodeError:
-                pass
-
         # When a server connection is lost and a query is attempted, most of
         # the time the query will raise a SERVER_LOST exception, then at the
         # second attempt to execute it, the mysql lib will reconnect and
@@ -111,36 +120,37 @@ class MySQLConnection(DBAPI):
         for count in range(3):
             try:
                 return cursor.execute(query)
-            except self.module.OperationalError, e:
-                if e.args[0] in (self.module.constants.CR.SERVER_GONE_ERROR, self.module.constants.CR.SERVER_LOST):
+            except self.module.OperationalError as e:
+                if e.args[0] in (self.module.constants.CR.SERVER_GONE_ERROR,
+                                 self.module.constants.CR.SERVER_LOST):
                     if count == 2:
-                        raise OperationalError(ErrorMessage(e))
+                        raise dberrors.OperationalError(ErrorMessage(e))
                     if self.debug:
                         self.printDebug(conn, str(e), 'ERROR')
                 else:
-                    raise OperationalError(ErrorMessage(e))
-            except self.module.IntegrityError, e:
+                    raise dberrors.OperationalError(ErrorMessage(e))
+            except self.module.IntegrityError as e:
                 msg = ErrorMessage(e)
                 if e.args[0] == self.module.constants.ER.DUP_ENTRY:
-                    raise DuplicateEntryError(msg)
+                    raise dberrors.DuplicateEntryError(msg)
                 else:
-                    raise IntegrityError(msg)
-            except self.module.InternalError, e:
-                raise InternalError(ErrorMessage(e))
-            except self.module.ProgrammingError, e:
-                raise ProgrammingError(ErrorMessage(e))
-            except self.module.DataError, e:
-                raise DataError(ErrorMessage(e))
-            except self.module.NotSupportedError, e:
-                raise NotSupportedError(ErrorMessage(e))
-            except self.module.DatabaseError, e:
-                raise DatabaseError(ErrorMessage(e))
-            except self.module.InterfaceError, e:
-                raise InterfaceError(ErrorMessage(e))
-            except self.module.Warning, e:
+                    raise dberrors.IntegrityError(msg)
+            except self.module.InternalError as e:
+                raise dberrors.InternalError(ErrorMessage(e))
+            except self.module.ProgrammingError as e:
+                raise dberrors.ProgrammingError(ErrorMessage(e))
+            except self.module.DataError as e:
+                raise dberrors.DataError(ErrorMessage(e))
+            except self.module.NotSupportedError as e:
+                raise dberrors.NotSupportedError(ErrorMessage(e))
+            except self.module.DatabaseError as e:
+                raise dberrors.DatabaseError(ErrorMessage(e))
+            except self.module.InterfaceError as e:
+                raise dberrors.InterfaceError(ErrorMessage(e))
+            except self.module.Warning as e:
                 raise Warning(ErrorMessage(e))
-            except self.module.Error, e:
-                raise Error(ErrorMessage(e))
+            except self.module.Error as e:
+                raise dberrors.Error(ErrorMessage(e))
 
     def _queryInsertID(self, conn, soInstance, id, names, values):
         table = soInstance.sqlmeta.table
@@ -168,13 +178,13 @@ class MySQLConnection(DBAPI):
             return "%s LIMIT %i" % (query, end)
         if not end:
             return "%s LIMIT %i, -1" % (query, start)
-        return "%s LIMIT %i, %i" % (query, start, end-start)
+        return "%s LIMIT %i, %i" % (query, start, end - start)
 
     def createReferenceConstraint(self, soClass, col):
         return col.mysqlCreateReferenceConstraint()
 
     def createColumn(self, soClass, col):
-        return col.mysqlCreateSQL()
+        return col.mysqlCreateSQL(self)
 
     def createIndexSQL(self, soClass, index):
         return index.mysqlCreateIndexSQL(soClass)
@@ -194,18 +204,19 @@ class MySQLConnection(DBAPI):
             # which is not always True (for an embedded application, e.g.)
             self.query('DESCRIBE %s' % (tableName))
             return True
-        except ProgrammingError, e:
-            if e[0].code == 1146: # ER_NO_SUCH_TABLE
+        except dberrors.ProgrammingError as e:
+            if e.args[0].code == 1146:  # ER_NO_SUCH_TABLE
                 return False
             raise
 
     def addColumn(self, tableName, column):
         self.query('ALTER TABLE %s ADD COLUMN %s' %
                    (tableName,
-                    column.mysqlCreateSQL()))
+                    column.mysqlCreateSQL(self)))
 
     def delColumn(self, sqlmeta, column):
-        self.query('ALTER TABLE %s DROP COLUMN %s' % (sqlmeta.table, column.dbName))
+        self.query('ALTER TABLE %s DROP COLUMN %s' % (sqlmeta.table,
+                                                      column.dbName))
 
     def columnsFromSchema(self, tableName, soClass):
         colData = self.queryAll("SHOW COLUMNS FROM %s"
@@ -217,11 +228,13 @@ class MySQLConnection(DBAPI):
             colClass, kw = self.guessClass(t)
             if self.kw.get('use_unicode') and colClass is col.StringCol:
                 colClass = col.UnicodeCol
-                if self.dbEncoding: kw['dbEncoding'] = self.dbEncoding
+                if self.dbEncoding:
+                    kw['dbEncoding'] = self.dbEncoding
             kw['name'] = soClass.sqlmeta.style.dbColumnToPythonAttr(field)
             kw['dbName'] = field
 
-            # Since MySQL 5.0, 'NO' is returned in the NULL column (SQLObject expected '')
+            # Since MySQL 5.0, 'NO' is returned in the NULL column
+            # (SQLObject expected '')
             kw['notNone'] = (nullAllowed.upper() != 'YES' and True or False)
 
             if default and t.startswith('int'):
@@ -244,8 +257,8 @@ class MySQLConnection(DBAPI):
             return col.IntCol, {}
         elif t.startswith('enum'):
             values = []
-            for i in t[5:-1].split(','): # take the enum() off and split
-                values.append(i[1:-1]) # remove the surrounding \'
+            for i in t[5:-1].split(','):  # take the enum() off and split
+                values.append(i[1:-1])  # remove the surrounding \'
             return col.EnumCol, {'enumValues': values}
         elif t.startswith('double'):
             return col.FloatCol, {}
@@ -255,7 +268,7 @@ class MySQLConnection(DBAPI):
                 colType = col.UnicodeCol
             if t.endswith('binary'):
                 return colType, {'length': int(t[8:-8]),
-                                       'char_binary': True}
+                                 'char_binary': True}
             else:
                 return colType, {'length': int(t[8:-1])}
         elif t.startswith('char'):
@@ -277,24 +290,30 @@ class MySQLConnection(DBAPI):
         elif t.startswith('bool'):
             return col.BoolCol, {}
         elif t.startswith('tinyblob'):
-            return col.BLOBCol, {"length": 2**8-1}
+            return col.BLOBCol, {"length": 2 ** 8 - 1}
         elif t.startswith('tinytext'):
-            return col.StringCol, {"length": 2**8-1, "varchar": True}
+            return col.StringCol, {"length": 2 ** 8 - 1, "varchar": True}
         elif t.startswith('blob'):
-            return col.BLOBCol, {"length": 2**16-1}
+            return col.BLOBCol, {"length": 2 ** 16 - 1}
         elif t.startswith('text'):
-            return col.StringCol, {"length": 2**16-1, "varchar": True}
+            return col.StringCol, {"length": 2 ** 16 - 1, "varchar": True}
         elif t.startswith('mediumblob'):
-            return col.BLOBCol, {"length": 2**24-1}
+            return col.BLOBCol, {"length": 2 ** 24 - 1}
         elif t.startswith('mediumtext'):
-            return col.StringCol, {"length": 2**24-1, "varchar": True}
+            return col.StringCol, {"length": 2 ** 24 - 1, "varchar": True}
         elif t.startswith('longblob'):
-            return col.BLOBCol, {"length": 2**32}
+            return col.BLOBCol, {"length": 2 ** 32}
         elif t.startswith('longtext'):
-            return col.StringCol, {"length": 2**32, "varchar": True}
+            return col.StringCol, {"length": 2 ** 32, "varchar": True}
         else:
             return col.Col, {}
 
+    def listTables(self):
+        return [v[0] for v in self.queryAll("SHOW TABLES")]
+
+    def listDatabases(self):
+        return [v[0] for v in self.queryAll("SHOW DATABASES")]
+
     def _createOrDropDatabase(self, op="CREATE"):
         self.query('%s DATABASE %s' % (op, self.db))
 
@@ -303,3 +322,35 @@ class MySQLConnection(DBAPI):
 
     def dropDatabase(self):
         self._createOrDropDatabase(op="DROP")
+
+    def server_version(self):
+        if self._server_version is not None:
+            return self._server_version
+        try:
+            server_version = self.queryOne("SELECT VERSION()")[0]
+            server_version = server_version.split('-', 1)
+            db_tag = "MySQL"
+            if len(server_version) == 2:
+                if "MariaDB" in server_version[1]:
+                    db_tag = "MariaDB"
+                server_version = server_version[0]
+            server_version = tuple(int(v) for v in server_version.split('.'))
+            server_version = (server_version, db_tag)
+        except:
+            server_version = None  # unknown
+        self._server_version = server_version
+        return server_version
+
+    def can_use_microseconds(self):
+        if self._can_use_microseconds is not None:
+            return self._can_use_microseconds
+        server_version = self.server_version()
+        if server_version is None:
+            return None
+        server_version, db_tag = server_version
+        if db_tag == "MariaDB":
+            can_use_microseconds = (server_version >= (5, 3, 0))
+        else:  # MySQL
+            can_use_microseconds = (server_version >= (5, 6, 4))
+        self._can_use_microseconds = can_use_microseconds
+        return can_use_microseconds
