@@ -1,13 +1,14 @@
 from sqlobject.dbconnection import DBAPI
 import re
 from sqlobject import col
+from sqlobject import dberrors
 from sqlobject import sqlbuilder
 from sqlobject.converters import registerConverter
-from sqlobject.dberrors import *
+
 
 class ErrorMessage(str):
     def __new__(cls, e, append_msg=''):
-        obj = str.__new__(cls, e[0] + append_msg)
+        obj = str.__new__(cls, e.args[0] + append_msg)
         if e.__module__ == 'psycopg2':
             obj.code = getattr(e, 'pgcode', None)
             obj.error = getattr(e, 'pgerror', None)
@@ -17,6 +18,7 @@ class ErrorMessage(str):
         obj.exception = e.__class__.__name__
         return obj
 
+
 class PostgresConnection(DBAPI):
 
     supportTransactions = True
@@ -44,13 +46,16 @@ class PostgresConnection(DBAPI):
                     import pgdb
                     self.module = pgdb
                 else:
-                    raise ValueError('Unknown PostgreSQL driver "%s", expected psycopg2, psycopg1 or pygresql' % driver)
+                    raise ValueError(
+                        'Unknown PostgreSQL driver "%s", '
+                        'expected psycopg2, psycopg1 or pygresql' % driver)
             except ImportError:
                 pass
             else:
                 break
         else:
-            raise ImportError('Cannot find a PostgreSQL driver, tried %s' % drivers)
+            raise ImportError(
+                'Cannot find a PostgreSQL driver, tried %s' % drivers)
         if driver.startswith('psycopg'):
             self.module = psycopg
             # Register a converter for psycopg Binary type.
@@ -122,11 +127,12 @@ class PostgresConnection(DBAPI):
     @classmethod
     def _connectionFromParams(cls, user, password, host, port, path, args):
         path = path.strip('/')
-        if (host is None) and path.count('/'): # Non-default unix socket
+        if (host is None) and path.count('/'):  # Non-default unix socket
             path_parts = path.split('/')
             host = '/' + '/'.join(path_parts[:-1])
             path = path_parts[-1]
-        return cls(host=host, port=port, db=path, user=user, password=password, **args)
+        return cls(host=host, port=port, db=path,
+                   user=user, password=password, **args)
 
     def _setAutoCommit(self, conn, auto):
         # psycopg2 does not have an autocommit method.
@@ -142,19 +148,22 @@ class PostgresConnection(DBAPI):
                 conn = self.module.connect(self.dsn)
             else:
                 conn = self.module.connect(**self.dsn_dict)
-        except self.module.OperationalError, e:
-            raise OperationalError(ErrorMessage(e, "used connection string %r" % self.dsn))
+        except self.module.OperationalError as e:
+            raise dberrors.OperationalError(
+                ErrorMessage(e, "used connection string %r" % self.dsn))
 
         # For printDebug in _executeRetry
         self._connectionNumbers[id(conn)] = self._connectionCount
 
-        if self.autoCommit: self._setAutoCommit(conn, 1)
+        if self.autoCommit:
+            self._setAutoCommit(conn, 1)
         c = conn.cursor()
         if self.schema:
             self._executeRetry(conn, c, "SET search_path TO " + self.schema)
         dbEncoding = self.dbEncoding
         if dbEncoding:
-            self._executeRetry(conn, c, "SET client_encoding TO '%s'" % dbEncoding)
+            self._executeRetry(conn, c,
+                               "SET client_encoding TO '%s'" % dbEncoding)
         return conn
 
     def _executeRetry(self, conn, cursor, query):
@@ -162,36 +171,34 @@ class PostgresConnection(DBAPI):
             self.printDebug(conn, query, 'QueryR')
         try:
             return cursor.execute(query)
-        except self.module.OperationalError, e:
-            raise OperationalError(ErrorMessage(e))
-        except self.module.IntegrityError, e:
+        except self.module.OperationalError as e:
+            raise dberrors.OperationalError(ErrorMessage(e))
+        except self.module.IntegrityError as e:
             msg = ErrorMessage(e)
             if e.pgcode == '23505':
-                raise DuplicateEntryError(msg)
+                raise dberrors.DuplicateEntryError(msg)
             else:
-                raise IntegrityError(msg)
-        except self.module.InternalError, e:
-            raise InternalError(ErrorMessage(e))
-        except self.module.ProgrammingError, e:
-            raise ProgrammingError(ErrorMessage(e))
-        except self.module.DataError, e:
-            raise DataError(ErrorMessage(e))
-        except self.module.NotSupportedError, e:
-            raise NotSupportedError(ErrorMessage(e))
-        except self.module.DatabaseError, e:
-            raise DatabaseError(ErrorMessage(e))
-        except self.module.InterfaceError, e:
-            raise InterfaceError(ErrorMessage(e))
-        except self.module.Warning, e:
+                raise dberrors.IntegrityError(msg)
+        except self.module.InternalError as e:
+            raise dberrors.InternalError(ErrorMessage(e))
+        except self.module.ProgrammingError as e:
+            raise dberrors.ProgrammingError(ErrorMessage(e))
+        except self.module.DataError as e:
+            raise dberrors.DataError(ErrorMessage(e))
+        except self.module.NotSupportedError as e:
+            raise dberrors.NotSupportedError(ErrorMessage(e))
+        except self.module.DatabaseError as e:
+            raise dberrors.DatabaseError(ErrorMessage(e))
+        except self.module.InterfaceError as e:
+            raise dberrors.InterfaceError(ErrorMessage(e))
+        except self.module.Warning as e:
             raise Warning(ErrorMessage(e))
-        except self.module.Error, e:
-            raise Error(ErrorMessage(e))
+        except self.module.Error as e:
+            raise dberrors.Error(ErrorMessage(e))
 
     def _queryInsertID(self, conn, soInstance, id, names, values):
         table = soInstance.sqlmeta.table
         idName = soInstance.sqlmeta.idName
-        sequenceName = soInstance.sqlmeta.idSequence or \
-                               '%s_%s_seq' % (table, idName)
         c = conn.cursor()
         if id is not None:
             names = [idName] + names
@@ -217,7 +224,7 @@ class PostgresConnection(DBAPI):
             return "%s LIMIT %i" % (query, end)
         if not end:
             return "%s OFFSET %i" % (query, start)
-        return "%s LIMIT %i OFFSET %i" % (query, end-start, start)
+        return "%s LIMIT %i OFFSET %i" % (query, end - start, start)
 
     def createColumn(self, soClass, col):
         return col.postgresCreateSQL()
@@ -240,8 +247,9 @@ class PostgresConnection(DBAPI):
         return 'INT NOT NULL'
 
     def tableExists(self, tableName):
-        result = self.queryOne("SELECT COUNT(relname) FROM pg_class WHERE relname = %s"
-                               % self.sqlrepr(tableName))
+        result = self.queryOne(
+            "SELECT COUNT(relname) FROM pg_class WHERE relname = %s" %
+            self.sqlrepr(tableName))
         return result[0]
 
     def addColumn(self, tableName, column):
@@ -250,7 +258,8 @@ class PostgresConnection(DBAPI):
                     column.postgresCreateSQL()))
 
     def delColumn(self, sqlmeta, column):
-        self.query('ALTER TABLE %s DROP COLUMN %s' % (sqlmeta.table, column.dbName))
+        self.query('ALTER TABLE %s DROP COLUMN %s' % (sqlmeta.table,
+                                                      column.dbName))
 
     def columnsFromSchema(self, tableName, soClass):
 
@@ -307,7 +316,9 @@ class PostgresConnection(DBAPI):
         for isPrimary, indexDef in primaryData:
             match = primaryRE.search(indexDef)
             assert match, "Unparseable contraint definition: %r" % indexDef
-            assert primaryKey is None, "Already found primary key (%r), then found: %r" % (primaryKey, indexDef)
+            assert primaryKey is None, \
+                "Already found primary key (%r), " \
+                "then found: %r" % (primaryKey, indexDef)
             primaryKey = match.group(1)
         if primaryKey is None:
             # VIEWs don't have PRIMARY KEYs - accept help from user
@@ -338,7 +349,8 @@ class PostgresConnection(DBAPI):
                 continue
             if field in keymap:
                 colClass = col.ForeignKey
-                kw = {'foreignKey': soClass.sqlmeta.style.dbTableToPythonClass(keymap[field])}
+                kw = {'foreignKey': soClass.sqlmeta.style.
+                      dbTableToPythonClass(keymap[field])}
                 name = soClass.sqlmeta.style.dbColumnToPythonAttr(field)
                 if name.endswith('ID'):
                     name = name[:-2]
@@ -361,17 +373,17 @@ class PostgresConnection(DBAPI):
         return results
 
     def guessClass(self, t):
-        if t.count('point'): # poINT before INT
+        if t.count('point'):  # poINT before INT
             return col.StringCol, {}
         elif t.count('int'):
             return col.IntCol, {}
         elif t.count('varying') or t.count('varchar'):
             if '(' in t:
-                return col.StringCol, {'length': int(t[t.index('(')+1:-1])}
-            else: # varchar without length in Postgres means any length
+                return col.StringCol, {'length': int(t[t.index('(') + 1:-1])}
+            else:  # varchar without length in Postgres means any length
                 return col.StringCol, {}
         elif t.startswith('character('):
-            return col.StringCol, {'length': int(t[t.index('(')+1:-1]),
+            return col.StringCol, {'length': int(t[t.index('(') + 1:-1]),
                                    'varchar': False}
         elif t.count('float') or t.count('real') or t.count('double'):
             return col.FloatCol, {}
