@@ -1,6 +1,7 @@
 from sqlobject.dbconnection import DBAPI
 from sqlobject import col
 
+
 class SybaseConnection(DBAPI):
 
     supportTransactions = False
@@ -8,7 +9,7 @@ class SybaseConnection(DBAPI):
     schemes = [dbName]
     NumericType = None
 
-    def __init__(self, db, user, password='', host='localhost',
+    def __init__(self, db, user, password='', host='localhost', port=None,
                  locking=1, **kw):
         db = db.strip('/')
         import Sybase
@@ -21,22 +22,22 @@ class SybaseConnection(DBAPI):
         self.module = Sybase
         self.locking = int(locking)
         self.host = host
+        self.port = port
         self.db = db
         self.user = user
         self.password = password
         autoCommit = kw.get('autoCommit')
         if autoCommit:
-           autoCommmit = int(autoCommit)
+            autoCommit = int(autoCommit)
         else:
             autoCommit = None
         kw['autoCommit'] = autoCommit
         DBAPI.__init__(self, **kw)
 
-    def connectionFromURI(cls, uri):
-        user, password, host, port, path, args = cls._parseURI(uri)
-        return cls(user=user, password=password, host=host or 'localhost',
-                   db=path, **args)
-    connectionFromURI = classmethod(connectionFromURI)
+    @classmethod
+    def _connectionFromParams(cls, user, password, host, port, path, args):
+        return cls(user=user, password=password,
+                   host=host or 'localhost', port=port, db=path, **args)
 
     def insert_id(self, conn):
         """
@@ -49,8 +50,9 @@ class SybaseConnection(DBAPI):
 
     def makeConnection(self):
         return self.module.connect(self.host, self.user, self.password,
-                              database=self.db, auto_commit=self.autoCommit,
-                              locking=self.locking)
+                                   database=self.db,
+                                   auto_commit=self.autoCommit,
+                                   locking=self.locking)
 
     HAS_IDENTITY = """
        SELECT col.name, col.status, obj.name
@@ -60,6 +62,7 @@ class SybaseConnection(DBAPI):
        WHERE obj.name = '%s'
              AND (col.status & 0x80) = 0x80
     """
+
     def _hasIdentity(self, conn, table):
         query = self.HAS_IDENTITY % table
         c = conn.cursor()
@@ -83,7 +86,7 @@ class SybaseConnection(DBAPI):
 
         q = self._insertSQL(table, names, values)
         if self.debug:
-            print 'QueryIns: %s' % q
+            self.printDebug(conn, q, 'QueryIns')
         c.execute(q)
         if has_identity and identity_insert_on:
             c.execute('SET IDENTITY_INSERT %s OFF' % table)
@@ -93,12 +96,12 @@ class SybaseConnection(DBAPI):
             self.printDebug(conn, id, 'QueryIns', 'result')
         return id
 
+    @classmethod
     def _queryAddLimitOffset(cls, query, start, end):
         # XXX Sybase doesn't support OFFSET
         if end:
             return "SET ROWCOUNT %i %s SET ROWCOUNT 0" % (end, query)
         return query
-    _queryAddLimitOffset = classmethod(_queryAddLimitOffset)
 
     def createReferenceConstraint(self, soClass, col):
         return None
@@ -116,7 +119,8 @@ class SybaseConnection(DBAPI):
     def joinSQLType(self, join):
         return 'NUMERIC(18,0) NOT NULL'
 
-    SHOW_TABLES="SELECT name FROM sysobjects WHERE type='U'"
+    SHOW_TABLES = "SELECT name FROM sysobjects WHERE type='U'"
+
     def tableExists(self, tableName):
         for (table,) in self.queryAll(self.SHOW_TABLES):
             if table.lower() == tableName.lower():
@@ -129,10 +133,14 @@ class SybaseConnection(DBAPI):
                     column.sybaseCreateSQL()))
 
     def delColumn(self, sqlmeta, column):
-        self.query('ALTER TABLE %s DROP COLUMN %s' % (sqlmeta.table, column.dbName))
+        self.query(
+            'ALTER TABLE %s DROP COLUMN %s' % (sqlmeta.table, column.dbName))
+
+    SHOW_COLUMNS = ('SELECT '
+                    'COLUMN_NAME, DATA_TYPE, IS_NULLABLE, COLUMN_DEFAULT '
+                    'FROM INFORMATION_SCHEMA.COLUMNS '
+                    'WHERE TABLE_NAME = \'%s\'')
 
-    SHOW_COLUMNS=('SELECT COLUMN_NAME, DATA_TYPE, IS_NULLABLE, COLUMN_DEFAULT FROM INFORMATION_SCHEMA.COLUMNS '
-                  'WHERE TABLE_NAME = \'%s\'')
     def columnsFromSchema(self, tableName, soClass):
         colData = self.queryAll(self.SHOW_COLUMNS
                                 % tableName)
