@@ -1,5 +1,9 @@
-from sqlobject import *
-from sqlobject.tests.dbtest import *
+import codecs
+import py.test
+from sqlobject import BoolCol, ForeignKey, IntCol, KeyCol, SQLObject, \
+    StringCol, connectionForURI, sqlhub
+from sqlobject.tests.dbtest import inserts, raises, setupClass, supports
+
 
 class TestSO1(SQLObject):
 
@@ -12,7 +16,8 @@ class TestSO1(SQLObject):
         cacheValues = False
 
     def _set_passwd(self, passwd):
-        self._SO_set_passwd(passwd.encode('rot13'))
+        self._SO_set_passwd(codecs.encode(passwd, 'rot13'))
+
 
 def setupGetters(cls):
     setupClass(cls)
@@ -20,14 +25,16 @@ def setupGetters(cls):
                   ('dave', 'dremel'), ('fred', 'forgo')],
             'name passwd')
 
+
 def test_case1():
     setupGetters(TestSO1)
     bob = TestSO1.selectBy(name='bob')[0]
     assert bob.name == 'bob'
-    assert bob.passwd == 'god'.encode('rot13')
+    assert bob.passwd == codecs.encode('god', 'rot13')
     bobs = TestSO1.selectBy(name='bob')[:10]
     assert len(list(bobs)) == 1
 
+
 def test_newline():
     setupGetters(TestSO1)
     bob = TestSO1.selectBy(name='bob')[0]
@@ -36,6 +43,7 @@ def test_newline():
     bob.expire()
     assert bob.name == testString
 
+
 def test_count():
     setupGetters(TestSO1)
     assert TestSO1.selectBy(name=None).count() == 0
@@ -43,6 +51,7 @@ def test_count():
     assert TestSO1.select(TestSO1.q.name == 'bob').count() == 1
     assert TestSO1.select().count() == len(list(TestSO1.select()))
 
+
 def test_getset():
     setupGetters(TestSO1)
     bob = TestSO1.selectBy(name='bob')[0]
@@ -52,6 +61,7 @@ def test_getset():
     bob.set(name='joebob', passwd='testtest')
     assert bob.name == 'joebob'
 
+
 def test_extra_vars():
     setupGetters(TestSO1)
     col = TestSO1.sqlmeta.columns['name']
@@ -59,37 +69,44 @@ def test_extra_vars():
     assert col.foobar == 1
     assert getattr(TestSO1.sqlmeta.columns['passwd'], 'title', None) is None
 
+
 class TestSO2(SQLObject):
     name = StringCol(length=50, dbName='name_col')
     passwd = StringCol(length=10)
 
     def _set_passwd(self, passwd):
-        self._SO_set_passwd(passwd.encode('rot13'))
+        self._SO_set_passwd(codecs.encode(passwd, 'rot13'))
+
 
 def test_case2():
     setupGetters(TestSO2)
     bob = TestSO2.selectBy(name='bob')[0]
     assert bob.name == 'bob'
-    assert bob.passwd == 'god'.encode('rot13')
+    assert bob.passwd == codecs.encode('god', 'rot13')
+
 
 class Student(SQLObject):
     is_smart = BoolCol()
 
+
 def test_boolCol():
     setupClass(Student)
     student = Student(is_smart=False)
-    assert student.is_smart == False
+    assert not student.is_smart
     student2 = Student(is_smart=1)
-    assert student2.is_smart == True
+    assert student2.is_smart
+
 
 class TestSO3(SQLObject):
     name = StringCol(length=10, dbName='name_col')
     other = ForeignKey('TestSO4', default=None)
     other2 = KeyCol(foreignKey='TestSO4', default=None)
 
+
 class TestSO4(SQLObject):
     me = StringCol(length=10)
 
+
 def test_foreignKey():
     setupClass([TestSO4, TestSO3])
     test3_order = [col.name for col in TestSO3.sqlmeta.columnList]
@@ -120,11 +137,12 @@ def test_foreignKey():
     tcc2 = TestSO3(name='c', other=tc4a.id)
     assert tcc2.other == tc4a
 
+
 def test_selectBy():
     setupClass([TestSO4, TestSO3])
     tc4 = TestSO4(me='another')
     tc3 = TestSO3(name='sel', other=tc4)
-    anothertc3 = TestSO3(name='not joined')
+    TestSO3(name='not joined')
     assert tc3.other == tc4
     assert list(TestSO3.selectBy(other=tc4)) == [tc3]
     assert list(TestSO3.selectBy(otherID=tc4.id)) == [tc3]
@@ -132,18 +150,22 @@ def test_selectBy():
     assert list(TestSO3.selectBy(otherID=tc4.id)[:10]) == [tc3]
     assert list(TestSO3.selectBy(other=tc4)[:10]) == [tc3]
 
+
 class TestSO5(SQLObject):
     name = StringCol(length=10, dbName='name_col')
     other = ForeignKey('TestSO6', default=None, cascade=True)
     another = ForeignKey('TestSO7', default=None, cascade=True)
 
+
 class TestSO6(SQLObject):
     name = StringCol(length=10, dbName='name_col')
     other = ForeignKey('TestSO7', default=None, cascade=True)
 
+
 class TestSO7(SQLObject):
     name = StringCol(length=10, dbName='name_col')
 
+
 def test_foreignKeyDestroySelfCascade():
     setupClass([TestSO7, TestSO6, TestSO5])
 
@@ -186,9 +208,10 @@ def test_foreignKeyDestroySelfCascade():
     assert TestSO6.select().count() == 0
     assert TestSO7.select().count() == 0
 
+
 def testForeignKeyDropTableCascade():
     if not supports('dropTableCascade'):
-        return
+        py.test.skip("dropTableCascade isn't supported")
     setupClass(TestSO7)
     setupClass(TestSO6)
     setupClass(TestSO5)
@@ -215,7 +238,7 @@ def testForeignKeyDropTableCascade():
     tc6b.destroySelf()
     assert TestSO5.select().count() == 1
     assert TestSO6.select().count() == 0
-    assert iter(TestSO5.select()).next() == tc5b
+    assert next(iter(TestSO5.select())) == tc5b
     tc6c = TestSO6(name='3')
     tc5b.other = tc6c
     assert TestSO5.select().count() == 1
@@ -224,13 +247,16 @@ def testForeignKeyDropTableCascade():
     assert TestSO5.select().count() == 0
     assert TestSO6.select().count() == 0
 
+
 class TestSO8(SQLObject):
     name = StringCol(length=10, dbName='name_col')
     other = ForeignKey('TestSO9', default=None, cascade=False)
 
+
 class TestSO9(SQLObject):
     name = StringCol(length=10, dbName='name_col')
 
+
 def testForeignKeyDestroySelfRestrict():
     setupClass([TestSO9, TestSO8])
 
@@ -253,13 +279,16 @@ def testForeignKeyDestroySelfRestrict():
     assert TestSO8.select().count() == 0
     assert TestSO9.select().count() == 0
 
+
 class TestSO10(SQLObject):
     name = StringCol()
 
+
 class TestSO11(SQLObject):
     name = StringCol()
     other = ForeignKey('TestSO10', default=None, cascade='null')
 
+
 def testForeignKeySetNull():
     setupClass([TestSO10, TestSO11])
     obj1 = TestSO10(name='foo')
@@ -276,33 +305,35 @@ def testForeignKeySetNull():
     assert dep2.other is None
     assert dep3.other is obj2
 
+
 def testAsDict():
     setupGetters(TestSO1)
     bob = TestSO1.selectBy(name='bob')[0]
     assert bob.sqlmeta.asDict() == {
         'passwd': 'tbq', 'name': 'bob', 'id': bob.id}
 
+
 def test_nonexisting_attr():
     setupClass(Student)
-    try:
-        Student.select(Student.q.nonexisting)
-    except AttributeError:
-        pass
-    else:
-        assert 0, "Expected an AttributeError"
+    raises(AttributeError, getattr, Student.q, 'nonexisting')
+
 
 class TestSO12(SQLObject):
     name = StringCol()
     value = IntCol(defaultSQL='1')
 
+
 def test_defaultSQL():
     setupClass(TestSO12)
     test = TestSO12(name="test")
     assert test.value == 1
 
+
 def test_connection_override():
     sqlhub.processConnection = connectionForURI('sqlite:///db1')
+
     class TestSO13(SQLObject):
         _connection = connectionForURI('sqlite:///db2')
+
     assert TestSO13._connection.uri() == 'sqlite:///db2'
     del sqlhub.processConnection
