@@ -1,20 +1,27 @@
-import py.test
-from sqlobject import *
-from sqlobject.tests.dbtest import *
-
-########################################
-## Date/time columns
-########################################
-
-from sqlobject import col
-col.default_datetime_implementation = DATETIME_IMPLEMENTATION
 from datetime import datetime, date, time
+import py.test
+
+from sqlobject import SQLObject
+from sqlobject import col
+from sqlobject.col import DATETIME_IMPLEMENTATION, DateCol, DateTimeCol, \
+    MXDATETIME_IMPLEMENTATION, TimeCol, mxdatetime_available, use_microseconds
+from sqlobject.tests.dbtest import getConnection, setupClass
+
+
+########################################
+# Date/time columns
+########################################
+
+
+col.default_datetime_implementation = DATETIME_IMPLEMENTATION
+
 
 class DateTime1(SQLObject):
     col1 = DateTimeCol()
     col2 = DateCol()
     col3 = TimeCol()
 
+
 def test_dateTime():
     setupClass(DateTime1)
     _now = datetime.now()
@@ -39,6 +46,7 @@ def test_dateTime():
     assert dt1.col3.minute == _now.minute
     assert dt1.col3.second == _now.second
 
+
 def test_microseconds():
     connection = getConnection()
     if hasattr(connection, 'can_use_microseconds') and \
@@ -76,12 +84,18 @@ if mxdatetime_available:
     col.default_datetime_implementation = MXDATETIME_IMPLEMENTATION
     from mx.DateTime import now, Time
 
-    dateFormat = None # use default
-    connection = getConnection()
-    if connection.dbName == "sqlite":
-        if connection.using_sqlite2:
-            # mxDateTime sends and PySQLite2 returns full date/time for dates
-            dateFormat = "%Y-%m-%d %H:%M:%S.%f"
+    dateFormat = None  # use default
+    try:
+        connection = getConnection()
+    except AttributeError:
+        # The module was imported during documentation building
+        pass
+    else:
+        if connection.dbName == "sqlite":
+            if connection.using_sqlite2:
+                # mxDateTime sends and PySQLite2 returns
+                # full date/time for dates
+                dateFormat = "%Y-%m-%d %H:%M:%S.%f"
 
     class DateTime2(SQLObject):
         col1 = DateTimeCol()
@@ -91,7 +105,8 @@ if mxdatetime_available:
     def test_mxDateTime():
         setupClass(DateTime2)
         _now = now()
-        dt2 = DateTime2(col1=_now, col2=_now, col3=Time(_now.hour, _now.minute, _now.second))
+        dt2 = DateTime2(col1=_now, col2=_now,
+                        col3=Time(_now.hour, _now.minute, _now.second))
 
         assert isinstance(dt2.col1, col.DateTimeType)
         assert dt2.col1.year == _now.year
