@@ -1,11 +1,16 @@
-from sqlobject import *
-from sqlobject.tests.dbtest import *
+import py.test
+from sqlobject import SQLObject
+from sqlobject.tests.dbtest import setupClass, supports
+
 
 class EmptyClass(SQLObject):
 
     pass
 
+
 def test_empty():
+    if not supports('emptyTable'):
+        py.test.skip("emptyTable isn't supported")
     setupClass(EmptyClass)
     e1 = EmptyClass()
     e2 = EmptyClass()
