@@ -1,15 +1,18 @@
-from dbtest import *
-from sqlobject import sqlhub, SQLObject, StringCol
+from __future__ import print_function
 import py.test
+
+from sqlobject import sqlhub, SQLObject, StringCol
 try:
     from sqlobject.wsgi_middleware import make_middleware
 except ImportError:
     pytestmark = py.test.mark.skipif('True')
+from .dbtest import getConnection, getConnectionURI, setupClass
 
 
 class NameOnly(SQLObject):
     name = StringCol()
 
+
 def makeapp(abort=False, begin=False, fail=False):
     def app(environ, start_response):
         NameOnly(name='app1')
@@ -26,33 +29,40 @@ def makeapp(abort=False, begin=False, fail=False):
         return ['ok']
     return app
 
+
 def makestack(abort=False, begin=False, fail=False, **kw):
     app = makeapp(abort=abort, begin=begin, fail=fail)
     app = make_middleware(app, {}, database=getConnectionURI(), **kw)
     return app
 
+
 def runapp(**kw):
-    print '-'*8
+    print('-' * 8)
     app = makestack(**kw)
     env = {}
+
     def start_response(*args):
         pass
+
     try:
         list(app(env, start_response))
         return True
     except AssertionError:
         return False
 
+
 def setup():
     setupClass(NameOnly)
     getConnection().query('DELETE FROM name_only')
     NameOnly._connection = sqlhub
 
+
 def names():
     names = [n.name for n in NameOnly.select(connection=getConnection())]
     names.sort()
     return names
 
+
 def test_fail():
     setup()
     assert not runapp(fail=True, use_transaction=True)
@@ -64,6 +74,7 @@ def test_fail():
     assert not runapp(fail=True, begin=True, use_transaction=True)
     assert names() == ['app1']
 
+
 def test_other():
     setup()
     assert runapp(fail=False, begin=True, use_transaction=True)
@@ -72,11 +83,10 @@ def test_other():
     # @@: Dammit, I can't get these to pass because I can't get the
     # stupid table to clear itself.  setupClass() sucks.  When I
     # fix it I'll take this disabling out:
-    return
+    py.test.skip("Oops...")
     assert names() == []
     assert runapp(fail=False, begin=True, abort=True, use_transaction=True)
     assert names() == ['app1']
     setup()
     assert runapp(use_transaction=True)
     assert names() == ['app1', 'app2']
-    
