@@ -1,20 +1,29 @@
-from sqlobject import *
-from sqlobject.tests.dbtest import *
+import py.test
+from sqlobject import PickleCol, SQLObject
+from sqlobject.tests.dbtest import setupClass, supports
+
 
 ########################################
-## Pickle columns
+# Pickle columns
 ########################################
 
+
 class PickleData:
     pi = 3.14156
+
     def __init__(self):
-        self.question = 'The Ulimate Question of Life, the Universe and Everything'
+        self.question = \
+            'The Ulimate Question of Life, the Universe and Everything'
         self.answer = 42
 
+
 class PickleContainer(SQLObject):
     pickledata = PickleCol(default=None, length=65535)
 
+
 def test_pickleCol():
+    if not supports('blobData'):
+        py.test.skip("blobData isn't supported")
     setupClass([PickleContainer], force=True)
     mypickledata = PickleData()
 
@@ -33,4 +42,3 @@ def test_pickleCol():
     assert s2.pi == mypickledata.pi
     assert s2.question == mypickledata.question
     assert s2.answer == mypickledata.answer
-
