@@ -1,16 +1,20 @@
-from sqlobject import *
-from sqlobject.tests.dbtest import *
+import py.test
+from sqlobject import SQLObject, UnicodeCol
+from sqlobject.tests.dbtest import getConnection, setupClass, supports
+
 
 ########################################
-## Schema per connection
+# Schema per connection
 ########################################
 
+
 class TestSchema(SQLObject):
     foo = UnicodeCol(length=200)
 
+
 def test_connection_schema():
     if not supports('schema'):
-        return
+        py.test.skip("schemas aren't supported")
     conn = getConnection()
     conn.schema = None
     conn.query('CREATE SCHEMA test')
